ReadAffy <- function(CDFfile=NULL,CELfiles=NULL,compress.cel=FALSE,
                     compress.cdf=FALSE,path="",verbose=T,chip.names=NULL){

  ##if CDF not given, find in path
  if(is.null(CDFfile)) CDFfile <- system(paste("ls ",path,"*.[cC][dD][fF]*",sep=""),intern=TRUE)
  if(length(CDFfile)!=1) stop(paste("CDFfile is not specified,exactly one CDF file must exist in directory:",path,"\n"))
  
  ##if CEL not given, use all in path
  if(is.null(CELfiles)) CELfiles <- system(paste("ls ",path,"*.[cC][eE][lL]*",sep=""),intern=TRUE)
  nchips <- length(CELfiles)
  if(nchips<1) stop(paste("CELfiles is not specified, at least one CEL file must exist in directory:",path,"\n"))
  
  ##if chip.names not defined use
  if(is.null(chip.names)){
    chip.names <- CELfiles
    chip.names <- as.character(sapply(chip.names,function(x) strsplit(x,"\\.")[[1]][1]))
  }
  else{
    if(length(chip.names)!=nchips){
      warning("Not the same number of chips than chip names. Assigning names from file.\n") 
      chip.names <- CELfiles
      chip.names <- as.character(sapply(chip.names,function(x) strsplit(x,"\\.")[[1]][1]))
    }
  }


  ##read in the CDF file
  if(verbose) cat("reading CDF file\n")
  info <- read.cdffile(CDFfile,compress=compress.cdf)
  if(verbose) cat("processing information\n")
  nrow <- dim(info$name)[1]
  ncol <- dim(info$name)[2]
  
  ##get the pm and mm information
  pm.or.mm <- as.vector(pmormm(info))

  pmindex <- which(pm.or.mm)
  mmindex <- which(!pm.or.mm)

  nprob <- length(pmindex)
  
  if(any((pmindex+ncol)-mmindex))
    warning("MMs are not underneath PMs\n")
  
  ##create the pm and mm matricex
  pm <- matrix(0,nprob,nchips)
  mm <- matrix(0,nprob,nchips)

  ##read in the CEL files
  if(verbose) cat("reading",nchips,"CEL files")
  for(i in 1:nchips){
    aux <- as.vector(read.celfile(CELfiles[i],compress=compress.cel,sd=FALSE)$intensity)
    if(nrow*ncol!=length(aux)) stop(paste(CELfiles[i],"doesn't match with CDFfile\n"))
    pm[,i] <- aux[pmindex]
    mm[,i] <- aux[mmindex]
    if(verbose) cat(".")
  }
  if(verbose) cat("\npreparing probe.level.object\n")
  
  ##get the rest of the information
  probe.ids <- as.vector(info$name)[pmindex]
  probe.numbers <- as.vector(info$atom)[pmindex]

  dimnames(pm) <- list(probe.ids,chip.names)
  dimnames(mm) <- list(probe.ids,chip.names)
  
  ##this will be used to get the coordinates
  xs <- rep(1:nrow,ncol)
  ys <- rep(1:ncol,rep(nrow,ncol))

  ret <- list(pm=pm,mm=mm,id=probe.ids,
              numbers=probe.numbers,names=info$name.level,
              n=length(info$name.level),
              x=xs[pmindex],y=ys[pmindex],ncol=ncol,nrow=nrow,
              nchips=nchips,nprob=nprob,chip.names=chip.names)

  class(ret) <- "plob"
  return(ret)
}


  
  
  
