\name{read.celfile}
\alias{read.celfile}
\title{Read CEL file data}
\description{
  Read the data contained in a CEL file.
}
\usage{
read.celfile(file, compress=FALSE, sd=TRUE, name=NULL,rm.mask=FALSE)
}
\arguments{
  \item{file}{the name of the preprocessed CEL file}
  \item{compress}{is the file compressed ?}
  \item{sd}{should the standard deviation for the intensities be
    returned ?}
  \item{name}{the name given to the CEL file (used for plots and else).}
  \item{rm.mask}{logical value. If \code{TRUE} the masked and outlier
    intensities are made NAs.}
}
\value{
  The object return is a list of class cel. It contains the
  following items
  \item{intensity}{a matrix of the intensity values given to the spots}
  \item{sd}{a matrix of the standard deviation values given to the
    spots, or \code{NA} if sd=FALSE}
}
\details{
  The \code{compress} argument allows to read the data directly from
  compressed files. The function calls C code using the zlib library:
  gzip and zip should be the only compression formats recognized.
  
  The parameter \code{sd} let one skip the information about pixel
  intensity standard deviation (in order to save memory for people who
  do not use it).
  
  When the parameter \code{name} is set to NULL (which is the default),
  the name is infered from the file name.
}
\note{
  If no zlib library could be found when the library was installed,
  trying to use the compression option will result in an error message.
}
\author{
  Laurent Gautier
}
%\examples{
%myCELfile <- read.celfile("path/to/my/cel/file.CEL")
%
%myCELfile <- read.celfile("path/to/my/gzippedfile/file.CEL.gz", compress=TRUE)
%}
\keyword{file}

